Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(5121)

Unified Diff: chrome/browser/chromeos/policy/device_cloud_policy_manager_chromeos.h

Issue 2603463003: Re-enable fetching component policies for login screen apps (Closed)
Patch Set: Rename the for-testing member Created 3 years, 12 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: chrome/browser/chromeos/policy/device_cloud_policy_manager_chromeos.h
diff --git a/chrome/browser/chromeos/policy/device_cloud_policy_manager_chromeos.h b/chrome/browser/chromeos/policy/device_cloud_policy_manager_chromeos.h
index 7a30322ceee7f429be3d66b31bbfab09997e0834..6d3b35179c1c99c7c1e601cefae380aa454c53ad 100644
--- a/chrome/browser/chromeos/policy/device_cloud_policy_manager_chromeos.h
+++ b/chrome/browser/chromeos/policy/device_cloud_policy_manager_chromeos.h
@@ -123,11 +123,12 @@ class DeviceCloudPolicyManagerChromeOS : public CloudPolicyManager {
// associated with this schema registry.
void SetSigninProfileSchemaRegistry(SchemaRegistry* schema_registry);
- // Sets whether the component cloud policy service should be created.
- // Defaults to true.
- void set_is_component_policy_enabled_for_testing(
- bool is_component_policy_enabled) {
- is_component_policy_enabled_ = is_component_policy_enabled;
+ // Sets whether the component cloud policy should be disabled (by skipping
+ // the component cloud policy service creation).
+ void set_component_policy_disabled_for_testing(
+ bool component_policy_disabled_for_testing) {
+ component_policy_disabled_for_testing_ =
+ component_policy_disabled_for_testing;
}
private:
@@ -175,12 +176,9 @@ class DeviceCloudPolicyManagerChromeOS : public CloudPolicyManager {
std::unique_ptr<ForwardingSchemaRegistry>
signin_profile_forwarding_schema_registry_;
- // Whether the component cloud policy service should be created.
- // TODO(emaxx): Change the default to true once both the client and the
- // DMServer are ready for handling policy fetches with the
- // google/chromeos/signinextension type. See crbug.com/666720,
- // crbug.com/644304 for reference.
- bool is_component_policy_enabled_ = false;
+ // Whether the component cloud policy should be disabled (by skipping the
+ // component cloud policy service creation).
+ bool component_policy_disabled_for_testing_ = false;
base::ObserverList<Observer, true> observers_;

Powered by Google App Engine
This is Rietveld 408576698